@@ -15,7 +15,9 @@ sub match {
     my $argv1 = shift // return undef;
 
     state $regex = qr{(?>
-         access[ ]denied[.][ ]ip[ ]name[ ]lookup[ ]failed
+         [ ]said:[ ]550[ ]blocked
+        |[(][^ ]+[@][^ ]+:blocked[)]
+        |access[ ]denied[.][ ]ip[ ]name[ ]lookup[ ]failed
         |access[ ]from[ ]ip[ ]address[ ][^ ]+[ ]blocked
         |all[ ]mail[ ]servers[ ]must[ ]have[ ]a[ ]ptr[ ]record[ ]with[ ]a[ ]valid[ ]reverse[ ]dns[ ]entry
         |bad[ ](:?dns[ ]ptr[ ]resource[ ]record|sender[ ]ip[ ]address)
@@ -57,11 +59,13 @@ sub match {
         |dnsbl:attrbl
         |dynamic/zombied/spam[ ]ips[ ]blocked
         |email[ ]blocked[ ]by[ ](?:[^ ]+[.]barracudacentral[.]org|spamhaus)
+        |error:[ ]no[ ]valid[ ]recipients[ ]from[ ]
         |esmtp[ ]not[ ]accepting[ ]connections  # icloud.com
         |fix[ ]reverse[ ]dns[ ]for[ ][^ ]+
         |go[ ]away
         |helo[ ]command[ ]rejected:
         |host[ ][^ ]+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]blocked
+        |host[ ]network[ ]not[ ]allowed
         |hosts[ ]with[ ]dynamic[ ]ip
         |http://(?:
              spf[.]pobox[.]com/why[.]html
@@ -72,7 +76,7 @@ sub match {
         |ip[/]domain[ ]reputation[ ]problems
         |ips[ ]with[ ]missing[ ]ptr[ ]records
         |is[ ](?:
-             in[ ]a[ ]black[ ]list[ ]at[ ][^ ]+[.]
+             in[ ]a[ ]black[ ]list(?:[ ]at[ ][^ ]+[.])?
             |in[ ]an[ ][^ ]+rbl[ ]on[ ][^ ]+
             |not[ ]allowed[ ]to[ ]send[ ](?:
                  mail[ ]from
@@ -82,6 +86,7 @@ sub match {
         |mail[ ]server[ ]at[ ][^ ]+[ ]is[ ]blocked
         |mail[ ]from[ ]\d+[.]\d+[.]\d+[.]\d[ ]refused:
         |message[ ]from[ ][^ ]+[ ]rejected[ ]based[ ]on[ ]blacklist
+        |message[ ]was[ ]rejected[ ]for[ ]possible[ ]spam/virus[ ]content
         |messages[ ]from[ ][^ ]+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
         |no[ ](?:
              access[ ]from[ ]mail[ ]server
@@ -95,6 +100,11 @@ sub match {
             |use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]isp
             )
         |ptr[ ]record[ ]setup
+        |rejected[ ]because[ ]the[ ]sending[ ]mta[ ]or[ ]the[ ]sender[ ]has[ ]not[ ]passed[ ]validation
+        |rejected[ ]due[ ]to[ ](?:
+             a[ ]poor[ ]email[ ]reputation[ ]score
+            |the[ ]sending[ ]mta's[ ]poor[ ]reputation
+            )
         |rejecting[ ]open[ ]proxy   # Sendmail(srvrsmtp.c)
         |reverse[ ]dns[ ](?:
               failed
@@ -123,19 +133,16 @@ sub match {
             |check:[ ]fail
             )
         |spf:[ ][^ ]+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail[.][ ][a-z0-9]_401
+        |temporarily[ ]deferred[ ]due[ ]to[ ]unexpected[ ]volume[ ]or[ ]user[ ]complaints
         |the[ ](?:email|domain|ip)[ ][^ ]+[ ]is[ ]blacklisted
         |this[ ]system[ ]will[ ]not[ ]accept[ ]messages[ ]from[ ]servers[/]devices[ ]with[ ]no[ ]reverse[ ]dns
+        |to[ ]submit[ ]messages[ ]to[ ]this[ ]e-mail[ ]system[ ]has[ ]been[ ]rejected
         |too[ ]many[ ](?:
              spams[ ]from[ ]your[ ]ip  # free.fr
             |unwanted[ ]messages[ ]have[ ]been[ ]sent[ ]from[ ]the[ ]following[ ]ip[ ]address[ ]above
             )
         |unresolvable[ ]relay[ ]host[ ]name
         |veuillez[ ]essayer[ ]plus[ ]tard[.][ ]service[ ]refused,[ ]please[ ]try[ ]later[.][ ][0-9a-z_]+(?:103|510)
-        |your[ ](?:
-             network[ ]is[ ]temporary[ ]blacklisted
-            |sender's[ ]ip[ ]address[ ]is[ ]listed[ ]at[ ][^ ]+[.]abuseat[.]org
-            |server[ ]requires[ ]confirmation
-            )
         |was[ ]blocked[ ]by[ ][^ ]+
         |we[ ]do[ ]not[ ]accept[ ]mail[ ]from[ ](?: # @mail.ru
              dynamic[ ]ips
@@ -146,8 +153,10 @@ sub match {
             |sending[ ]spam
             )
         |your[ ](?:
-             access[ ]to[ ]submit[ ]messages[ ]to[ ]this[ ]e-mail[ ]system[ ]has[ ]been[ ]rejected
-            |message[ ]was[ ]rejected[ ]for[ ]possible[ ]spam/virus[ ]content
+             email[ ]address[ ]has[ ]been[ ]blacklisted
+            |network[ ]is[ ]temporary[ ]blacklisted
+            |sender's[ ]ip[ ]address[ ]is[ ]listed[ ]at[ ][^ ]+[.]abuseat[.]org
+            |server[ ]requires[ ]confirmation
             )
         )
     }x;
@@ -222,7 +231,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
