@@ -3,9 +3,14 @@ use feature ':5.10';
 use strict;
 use warnings;
 use Encode;
-use Encode::Guess;
 use Digest::SHA;
 
+my $EncodingsC = [qw/big5-eten gb2312/];
+my $EncodingsE = [qw/iso-8859-1/];
+my $EncodingsJ = [qw/7bit-jis iso-2022-jp euc-jp shiftjis/];
+use Encode::Guess; Encode::Guess->add_suspects(@$EncodingsC, @$EncodingsE, @$EncodingsJ);
+sub encodenames { return [@$EncodingsC, @$EncodingsE, @$EncodingsJ] };
+
 sub token {
     # Create the message token from an addresser and a recipient
     # @param    [String] addr1  A sender's email address
@@ -213,7 +218,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2019,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
